==> apache-log4j-2.22.0-src.zip: log4j-core-test/src/test/java/org/apache/logging/log4j/core/net/ssl/EnvironmentPasswordProviderTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.logging.log4j.core.net.ssl;

import static org.junit.jupiter.api.Assertions.*;

import org.junit.jupiter.api.Test;

public class EnvironmentPasswordProviderTest {

    @Test
    public void testConstructorDisallowsNull() {
        assertThrows(NullPointerException.class, () -> new EnvironmentPasswordProvider(null));
    }

    @Test
    public void testGetPasswordReturnsEnvironmentVariableValue() {
        final String value = System.getenv("PATH");
        if (value == null) {
            return; // we cannot test in this environment
        }
        final char[] actual = new EnvironmentPasswordProvider("PATH").getPassword();
        assertArrayEquals(value.toCharArray(), actual);
    }
}

==> apache-log4j-2.25.2-src.zip: log4j-core-test/src/test/java/org/apache/logging/log4j/core/net/ssl/EnvironmentPasswordProviderTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.logging.log4j.core.net.ssl;

import static org.junit.jupiter.api.Assertions.assertArrayEquals;
import static org.junit.jupiter.api.Assertions.assertThrows;

import org.junit.jupiter.api.Test;

class EnvironmentPasswordProviderTest {

    @Test
    void testConstructorDisallowsNull() {
        assertThrows(NullPointerException.class, () -> new EnvironmentPasswordProvider(null));
    }

    @Test
    void testGetPasswordReturnsEnvironmentVariableValue() {
        final String value = System.getenv("PATH");
        if (value == null) {
            return; // we cannot test in this environment
        }
        final char[] actual = new EnvironmentPasswordProvider("PATH").getPassword();
        assertArrayEquals(value.toCharArray(), actual);
    }
}
